@@ -1,7 +1,7 @@
 package App::ANSIColorUtils;
 
 our $DATE = '2019-02-13'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -44,6 +44,45 @@ sub show_ansi_color_table {
     [200, "OK", \@rows];
 }
 
+$SPEC{show_assigned_rgb_colors} = {
+    v => 1.1,
+    summary => 'Take arguments, pass them through assign_rgb_color(), show the results',
+    description => <<'_',
+
+`assign_rgb_color()` from <pm:Color::RGB::Util> takes a string, produce SHA1
+digest from it, then take 24bit from the digest as the assigned color.
+
+_
+    args => {
+        strings => {
+            schema => ['array*', of=>'str*'],
+            req => 1,
+            pos => 0,
+            greedy => 1,
+        },
+    },
+};
+sub show_assigned_rgb_colors {
+    require Color::ANSI::Util;
+    require Color::RGB::Util;
+
+    my %args = @_;
+
+    my $strings = $args{strings};
+
+    my @rows;
+    for (0 .. $#{ $strings }) {
+        my $str = $strings->[$_];
+        my $rgb = Color::RGB::Util::assign_rgb_color($str);
+        push @rows, {
+            number => $_+1,
+            string => $str,
+            color  => sprintf("%s%s\e[0m", Color::ANSI::Util::ansifg($rgb), "'$str' is assigned color #$rgb"),
+        };
+    }
+    [200, "OK", \@rows, {"table.fields" => [qw/number color/]}];
+}
+
 1;
 # ABSTRACT: Utilities related to ANSI color
 
@@ -59,7 +98,7 @@ App::ANSIColorUtils - Utilities related to ANSI color
 
 =head1 VERSION
 
-This document describes version 0.002 of App::ANSIColorUtils (from Perl distribution App-ANSIColorUtils), released on 2019-02-13.
+This document describes version 0.003 of App::ANSIColorUtils (from Perl distribution App-ANSIColorUtils), released on 2019-02-13.
 
 =head1 DESCRIPTION
 
@@ -93,6 +132,8 @@ This distributions provides the following command-line utilities:
 
 =item * L<show-ansi-color-table>
 
+=item * L<show-assigned-rgb-colors>
+
 =back
 
 =head1 FUNCTIONS
@@ -127,6 +168,39 @@ that contains extra information.
 
 Return value:  (any)
 
+
+=head2 show_assigned_rgb_colors
+
+Usage:
+
+ show_assigned_rgb_colors(%args) -> [status, msg, payload, meta]
+
+Take arguments, pass them through assign_rgb_color(), show the results.
+
+C<assign_rgb_color()> from L<Color::RGB::Util> takes a string, produce SHA1
+digest from it, then take 24bit from the digest as the assigned color.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<strings>* => I<array[str]>
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/App-ANSIColorUtils>.
